******************
Command-line tools
******************

conda_envfile_parse
===================

.. argparse::
    :module: conda_envfile
    :func: _conda_envfile_parse_parser
    :prog: conda_envfile_parse

conda_envfile_merge
===================

.. argparse::
    :module: conda_envfile
    :func: _conda_envfile_merge_parser
    :prog: conda_envfile_merge

conda_envfile_diff
==================

.. argparse::
    :module: conda_envfile
    :func: _conda_envfile_diff_parser
    :prog: conda_envfile_diff

conda_envfile_pyproject
=======================

.. argparse::
    :module: conda_envfile
    :func: _conda_envfile_pyproject_parser
    :prog: conda_envfile_pyproject

conda_envfile_restrict
======================

.. argparse::
    :module: conda_envfile
    :func: _conda_envfile_restrict_parser
    :prog: conda_envfile_restrict
